import React, {
  useState,
  useCallback,
  useEffect,
} from 'react';
import ReactDOM from 'react-dom';
import {
 csv,
  scaleLinear,
  max,
  format,
  extent
} from 'd3';
import { useData } from './useData';
import { AxisBottom } from './AxisBottom';
import { AxisLeft } from './AxisLeft';
import { Marks } from './Marks';
import {Dropdown} from './Dropdown';

let menuHeight = 75;

const width = 960;
const height = 500 - menuHeight;
const margin = {
  top: 20,
  right: 40,
  bottom: 65,
  left: 90,
};
const innerHeight =
  height - margin.top - margin.bottom;
const innerWidth =
  width - margin.left - margin.right;
const xAxisLabelOffset = 50;
const yAxisLabelOffset = 50;


const attributes = [

{value: 'sepal_length', label: 'Sepal Length'},
{value: 'sepal_width', label: 'Sepal width'},
{value: 'petal_length', label: 'Petal length'},
{value: 'petal_width', label: 'Petal width'}
];

const getLabel = value => {
	for (let i=0; i<attributes.length; i++) {
		if(attributes[i].value === value) {
      return attributes[i].label;
    }
	}
  return '';
};

const App = () => {
  
  
  const initalXAttribute = 'petal_length';
    
	const [xAttribute, setXAttribute] = useState(initalXAttribute);  
  
    const initalYAttribute = 'sepal_width';
    
	const [yAttribute, setYAttribute] = useState(initalYAttribute);  
  
  
  
  const data = useData();

  console.log(data);
  
  
  if (!data) {
    return <pre>Loading...</pre>;
  }

  const xValue = d => d[xAttribute];
  const yValue = d => d[yAttribute];
  

  
  
  
 const xAxisLabel = getLabel(xAttribute);
const yAxisLabel = getLabel(yAttribute);
  
  
  const xScale = scaleLinear()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
  .nice();

  
  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([0, innerHeight])



  //console.log(xScale.ticks());


  


  
  
  return (
    <>
      <label for="x-select">X:</label> 
  <Dropdown 
    
    options = {attributes}
    id="x-select"
    selectedValue = {xAttribute}
    onSelectedValueChange = {setXAttribute}
    
    />
       <label for="x-select">Y:</label> 
  <Dropdown 
    
    options = {attributes}
    id="y-select"
    selectedValue = {yAttribute}
    onSelectedValueChange = {setYAttribute}
    
    />
    <svg width={width} height={height}>
      <g
        transform={`translate(${margin.left},${margin.top})`}
      >
        <AxisBottom
          xScale={xScale}
          innerHeight={innerHeight}
          tickFormat = {n=>format('.2s')(n)}
          tickOffset = {5}
        />
        <AxisLeft yScale={yScale} innerWidth={innerWidth}  tickOffset = {5}/>
         <text className="axis-label" 
           
          textAnchor="middle"
           transform = {`translate(${-yAxisLabelOffset}, ${innerHeight/2} ) rotate(-90) `}
           >{yAxisLabel}</text>
        

        <text className="axis-label" x={innerWidth/2} 
          y={innerHeight + xAxisLabelOffset}
          textAnchor="middle" >{xAxisLabel}</text>
        
        
        <Marks
          data={data}
          xScale={xScale}
          yScale={yScale}
          xValue = {xValue}
          yValue = {yValue}
          circleRadius = {7}
        />
      </g>
    </svg>
    </>  
  );
      
};

const rootElement = document.getElementById(
  'root'
);

ReactDOM.render(<App />, rootElement);
